@@ -1,4 +1,5 @@
-## Copyright 2015-2016 Oliver Heimlich
+## Copyright 2015 Oliver Heimlich
+## Copyright 2018 Joel Dahne
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -17,15 +18,16 @@
 ## @documentencoding UTF-8
 ## @defmethod {@@infsup} mince (@var{X})
 ## @defmethodx {@@infsup} mince (@var{X}, @var{N})
-## 
+##
 ## Mince interval @var{X} into a row vector of @var{N} sub-intervals of equal
 ## size.
 ##
 ## The sub-intervals are returned in ascending order and may overlap due to
 ## round-off errors.
 ##
-## If @var{X} is not a scalar, the result is a matrix.  The default value for
-## @var{N} is 100.
+## If @var{X} is a vector it is converted to a column vector and the
+## result is a matrix where the rows are independent sequences.  The
+## default value for @var{N} is 100.
 ##
 ## Accuracy: The result is an accurate enclosure.
 ##
@@ -46,35 +48,45 @@
 
 function x = mince (x, n)
 
-if (nargin > 2)
+  if (nargin > 2)
     print_usage ();
     return
-endif
-if (not (isa (x, "infsup")))
+  endif
+  if (not (isa (x, "infsup")))
     x = infsup (x);
-endif
-if (nargin < 2)
+  endif
+  if (nargin < 2)
     n = 100;
-endif
+  endif
 
-base = limit = x;
-idx.type = '()';
-idx.subs = {isfinite(x.inf)};
-base = subsasgn (base, idx, infsup (subsref (x.inf, idx)));
-idx.subs = {isfinite(x.sup)};
-limit = subsasgn (limit, idx, infsup (subsref (x.sup, idx)));
+  if (not (isvector (x)))
+    error ("linspace: x must be a scalar or a vector");
+  endif
 
-boundaries = linspace (base, limit, n + 1);
-l = boundaries.inf(:, 1 : end - 1);
-u = boundaries.sup(:, 2 : end);
+  ## Convert x to a column vector
+  x = reshape (x, [], 1);
 
-empty = vec (isempty (x));
-l(empty, :) = inf;
-u(empty, :) = -inf;
+  base = limit = x;
+  idx.type = '()';
+  idx.subs = {isfinite(x.inf)};
+  base = subsasgn (base, idx, infsup (subsref (x.inf, idx)));
+  idx.subs = {isfinite(x.sup)};
+  limit = subsasgn (limit, idx, infsup (subsref (x.sup, idx)));
 
-x.inf = l;
-x.sup = u;
+  boundaries = linspace (base, limit, n + 1);
+
+  l = boundaries.inf(:, 1 : end - 1);
+  u = boundaries.sup(:, 2 : end);
+
+  empty = vec (isempty (x));
+  l(empty, :) = inf;
+  u(empty, :) = -inf;
+
+  x.inf = l;
+  x.sup = u;
 
 endfunction
 
 %!assert (isequal (mince (infsup (0, 10), 10), infsup (0 : 9, 1 : 10)));
+
+%!assert (size (mince (infsup (zeros (1, 0), ones (1, 0)), 2)), [0 2]);
