@@ -1,4 +1,5 @@
 ## Copyright 2015 Oliver Heimlich
+## Copyright 2018 Joel Dahne
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -24,8 +25,9 @@
 ## The sub-intervals are returned in ascending order and may overlap due to
 ## round-off errors.
 ##
-## If @var{X} is not a scalar, the result is a matrix.  The default value for
-## @var{N} is 100.
+## If @var{X} is a vector it is converted to a column vector and the
+## result is a matrix where the rows are independent sequences.  The
+## default value for @var{N} is 100.
 ##
 ## Accuracy: The result is an accurate enclosure.
 ##
@@ -57,9 +59,18 @@ function result = mince (x, n)
     n = 100;
   endif
 
+  if (not (isvector (x)))
+    error ("linspace: x must be a scalar or a vector");
+  endif
+
+  ## Convert x to a column vector
+  x = reshape (x, [], 1);
+
   result = infsupdec (mince (x.infsup, n), "trv");
   result.dec = min (result.dec, x.dec);
 
 endfunction
 
 %!assert (isequal (mince (infsupdec (0, 10), 10), infsupdec (0 : 9, 1 : 10, "trv")));
+
+%!assert (size (mince (infsupdec (zeros (1, 0), ones (1, 0)), 2)), [0 2]);
